-- 灵魂分解
Lua_GatherSoulResolveWindow = class("Lua_GatherSoulResolveWindow", Lua_SecondSizeWindow)
function Lua_GatherSoulResolveWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_GatherSoulResolveWindow";
	self.skinName = "SoulResolveWindow_skin";
	self.titleText = LanUtil.getValue(124402);
end

function Lua_GatherSoulResolveWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.resolveArr = Array();

	self.recordsList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 1023, 367));
	self.recordsList:setLocation(0, 21, 0);
	self.recordsList:setListCell(Lua_GatherSoulResolveItem, 160, 170.5, 6);

	self.help:addClickFuntion(self, self.onHelpClick);
	self.resolveBtn:addClickFuntion(self, self.onResolveClick);
	self.subBtn:addClickFuntion(self, self.onSelectSoulClick); -- 选择分解类型
	self.selectCheckBox:addBoxChange(self, self.onSelectBoxClick); -- 自动分解选择

	self:setSelectType(DataCenter.gatherSoulData.select_num);
	self:onUpdatePackInfo();
	self:onResolveSoulData();

	self:addLuaEvent("rOpenGatherSoulPanelInfo", self, self.onResolveSoulData);
	self:addLuaEvent("rOpenGatherSoulPanelInfo", self, self.onUpdatePackInfo); -- 分解灵纹后刷新界面
	self:addLuaEvent("PACK_GATHERSOUL_UPDATE", self, self.onUpdatePackInfo); -- 背包获取新灵魂后刷新界面
	self:addLuaEvent("ISSELCET", self, self.onSelectInfo);
	self:addLuaEvent("PACK_GATHERSOUL_UPDATE", self, self.onResolveSoulData); -- 背包获取新灵纹更新分解数据
end

function Lua_GatherSoulResolveWindow:onSelectSoulClick(go)
	local dragData = {};
	dragData.datas = Array();
	dragData.datas:add(LanUtil.getValue(124423));
	dragData.datas:add(LanUtil.getValue(124424));
	dragData.datas:add(LanUtil.getValue(124425));
	dragData.datas:add(LanUtil.getValue(124426));
	dragData.datas:add(LanUtil.getValue(124427));
	dragData.offsetX = -435;
	dragData.offsetY = -94;
	dragData.callBackOwner = self;
	dragData.callBack = self.onDragDownCallBack;
	dragData.selected = self.selectType;
	Lua_WindowUtil.openWin("Lua_DragDownWindow", nil, dragData);
end

function Lua_GatherSoulResolveWindow:onDragDownCallBack(val)
	Lua_ProxyManager.getProxy("Lua_GatherSoulProxy"):sAutoResolveSelectType(DataCenter.gatherSoulData.isAutoResolve,val);
	self:setSelectType(val);
	self:onUpdatePackInfo();
	self:onResolveSoulData();
end

function Lua_GatherSoulResolveWindow:setSelectType(val)
	self.selectType = val;
	if val == 1 then -- 绿色
		self.subTxt.text = LanUtil.getValue(124417);
	elseif val == 2 then -- 蓝色
		self.subTxt.text = LanUtil.getValue(124418);
	elseif val == 3 then -- 紫色
		self.subTxt.text = LanUtil.getValue(124419);
	elseif val == 4 then -- 橙色
		self.subTxt.text = LanUtil.getValue(124420);
	elseif val == 5 then -- 红色
		self.subTxt.text = LanUtil.getValue(124421);
	end
end

function Lua_GatherSoulResolveWindow:onResolveSoulData()--分解数据
	self.resolveArr:clear();
	local arr = Array();
	local len = self.resolveList:getSize();
	for i = 1, len do
		if self.resolveList[i].isSelect == true then
			self.resolveArr:add({id = self.resolveList[i].vo.id, index = self.resolveList[i].vo.index, color = self.resolveList[i].vo.color,
			decompose = self.resolveList[i].vo.decompose, type = self.resolveList[i].vo.soul_type});        
		end
	end

	if self.resolveArr:getSize() > 0  then
		local resolveNum = DataCenter.gatherSoulUtil:soulResolveNum(self.resolveArr);
		self.resolveTxt.text = LanUtil.formateStr(LanUtil.getValue(124407), tostring(DataCenter.gatherSoulData.soulDust), tostring(resolveNum));
	else
		self.resolveTxt.text = LanUtil.formateStr(LanUtil.getValue(124422), tostring(DataCenter.gatherSoulData.soulDust));
	end
	self:updateIsShowResolveRed();
end

-- 点击 单个灵纹 刷新界面
function Lua_GatherSoulResolveWindow:onSelectInfo()
	self:onResolveSoulData();
	self:updateSelect();
end

-- 背包数据
function Lua_GatherSoulResolveWindow:onUpdatePackInfo()
	self.resolveList = Array();
	local bagData = DataCenter.packData:getBagType(Lua_PackData.JH_PACK);
	local arr = bagData:getBagAllData();      
	local len = arr:getSize();
	for i = 1, len do
		for j = i + 1, len do
			if not DataCenter.gatherSoulData:sortResolvePackFun(arr[i], arr[j]) then
				local temp = arr[i]
				arr[i] = arr[j]
				arr[j] = temp
			end
		end

		if arr[i].prop_type == 1 or arr[i].soul_type == 2 then
			self.resolveList:add({vo = arr[i], isSelect = self:checkSelect(arr[i])});
		end
	end

	if  DataCenter.gatherSoulData.isAutoResolve == 0 then
		self.selectCheckBox.seleted = false;
	else
		self.selectCheckBox.seleted = true;
	end
	self.recordsList:setLuaArrayData(self.resolveList, false);
end

function Lua_GatherSoulResolveWindow:sortFun(a, b)
	if a == nil or b == nil then
		return false;
	end

	if a.color > b.color then
		return true;
	elseif a.color == b.color then
		if tonumber(a.id) > tonumber(b.id) then
			return true;
		elseif tonumber(a.id) == tonumber(b.id) then
			if a.rune_level > b.rune_level then
				return true;
			end
		end
	end
	return false;
end

function Lua_GatherSoulResolveWindow:checkSelect(vo)
	if vo == nil then
		return false;
	end

	if (self.selectType == 1 and vo.color == 1) or vo.soul_type == 2 then
		return true;
	elseif (self.selectType == 2 and vo.color <= 2) or vo.soul_type == 2 then
		return true;
	elseif (self.selectType == 3 and vo.color <= 3) or vo.soul_type == 2 then
		return true;
	elseif (self.selectType == 4 and vo.color <= 4) or vo.soul_type == 2 then
		return true;
	elseif (self.selectType == 5 and vo.color <= 5) or vo.soul_type == 2 then
		return true;
	end
	return false;
end


function Lua_GatherSoulResolveWindow:onResolveTipsClick()
	Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {owner = self, des = LanUtil.getValue(124416), type = 1, subFun = self.onSubCallback});
end

function Lua_GatherSoulResolveWindow:onResolveClick()
	local isResolve = false;
	local len = self.resolveArr:getSize()
	if len > 0 then
		for i = 1, len do
			if self.resolveArr[i].type ~= 2 then
				if self.resolveArr[i].color >=4 then
					isResolve = true;
				end
			end
		end

		if isResolve then
			self:onResolveTipsClick();
		else
			self:onSubCallback();
		end
	else
		OperateAlert.show(LanUtil.getValue(124451));
	end
end

function Lua_GatherSoulResolveWindow:onSubCallback()
	Lua_ProxyManager.getProxy("Lua_GatherSoulProxy"):sResolveSoul(self.resolveArr);
	if self.resolveList ~= nil then
		self.resolveList:clear();
	end
end

function Lua_GatherSoulResolveWindow:onSelectBoxClick(state)
	Lua_ProxyManager.getProxy("Lua_GatherSoulProxy"):sAutoResolveSelectType(state and 1 or 0, DataCenter.gatherSoulData.select_num);
end

function Lua_GatherSoulResolveWindow:updateSelect()
	if self.recordsList ~= nil then
		local arr = self.recordsList.showList;
		local len = arr:getSize();
		for i = 1, len do
			arr[i]:updateSelect();
		end
	end
end

-- 分解红点显示
function Lua_GatherSoulResolveWindow:updateIsShowResolveRed()
	local isShowResolveRed = DataCenter.gatherSoulData:isShowSoulResolveRed();
	self:showRedDot(isShowResolveRed);
end

function Lua_GatherSoulResolveWindow:showRedDot(val)
	if val then
		if self.redDot == nil then
			self.redDot = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_hongdian", 515, -232, 0, 0);
			self.redDot:setDepth(7);
			self.redDot.name = "redDot";
		end
		self.redDot:setEnable(true);
	else
		if self.redDot ~= nil then
			self.redDot:setEnable(false);
		end
	end
end

function Lua_GatherSoulResolveWindow:onHelpClick()
	Lua_WindowUtil.openWin("Lua_RuleTipWindow", WinParam.ACTION_AUTO, LanUtil.getValue(124428));
end

function Lua_GatherSoulResolveWindow:dispose()
	if self.resolveArr ~= nil then
		self.resolveArr:dispose();
		self.resolveArr:clear();
		self.resolveArr = nil; 
	end
	if self.recordsList ~= nil then
		self.recordsList:dispose()
		self.recordsList = nil;
	end
	if self.resolveList ~= nil then
		self.resolveList:dispose();
		self.resolveList:clear();
		self.resolveList = nil; 
	end
	if self.redDot ~= nil then
		self.redDot:dispose();
		self.redDot = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_GatherSoulResolveItem = class("Lua_GatherSoulResolveItem", Lua_ListCell);
function Lua_GatherSoulResolveItem:ctor(p)
	self:superCall("ctor", p, "SoulResolveItem_skin");
end

function Lua_GatherSoulResolveItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemImage = Lua_ToolImage.new(self.content);
	self.itemImage:setDepth(3);
	self.itemImage:setCanClick(false);
	self.itemImage:setLocation(0, 39, 0);
end

 function Lua_GatherSoulResolveItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.itemImage.data = data.vo;
	self.soulNameLab.text = data.vo.soulUpgradeName;
	self.soulDesLab.text = data.vo.soulResolveProp;
	self:updateSelect();
 end

function Lua_GatherSoulResolveItem:updateSelect()
	self.selectIcon:setEnable(self.data.isSelect);
	self.itemImage:setGray(self.data.isSelect);
end

function Lua_GatherSoulResolveItem:onPlayerSoundClick(go)
	self.data.isSelect = not self.data.isSelect;
	Lua_MsgUtil.callFunc("ISSELCET");
end

function Lua_GatherSoulResolveItem:dispose()
	if self.itemImage ~= nil then
		self.itemImage:dispose();
		self.itemImage = nil;
	end
	self.data = nil;

    self:superCall("dispose");
end