Lua_RuneResolvePanel = class("Lua_RuneResolvePanel", Lua_DisplayObject);
function Lua_RuneResolvePanel:ctor(p)
	self:superCall("ctor", p, "RuneResolvePanel_skin");
end

function Lua_RuneResolvePanel:buildShowItem()
	self:superCall("buildShowItem");

	self.resolveArr = Array();

	self.recordsList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 680, 444));
	self.recordsList:setLocation(160, -30, 0);
	self.recordsList:setListCell(Lua_RuneResolveItem, 172, 170, 4);

	self.suipianbg.clickScale = false;
	self.chipBg.clickScale = false;
	self.suipianbg:addClickFuntion(self, self.onOpenRuneStoneTips);
	self.chipBg:addClickFuntion(self, self.onOpenRuneSoulTips);
	self.resolveButton:addClickFuntion(self, self.onResolveClick);

	self.blueCheckBox.seleted = true;
	self.blueCheckBox:addBoxChange(self, self.onBlueBoxClick);
	self.purpleCheckBox:addBoxChange(self, self.onPurpleBoxClick);
	self.orangeCheckBox:addBoxChange(self, self.onOrangeBoxClick);
	self.redCheckBox:addBoxChange(self, self.onRedBoxClick);

	self:onUpdateRecords();
	self:onResolveRune();
	self:exeRuneSelect();
	self:showResolveEffect();

	self:addLuaEvent("rResolveRune", self, self.onResolveRune)
	self:addLuaEvent("rResolveRune", self, self.onUpdateRecords) -- 分解灵纹后刷新界面
	self:addLuaEvent("PACK_RUNE_UPDATE", self, self.onUpdateRecords) -- 背包获取新灵纹后刷新灵纹界面
	self:addLuaEvent("ISSELCET", self, self.onSelectInfo)
	self:addLuaEvent("PACK_RUNE_UPDATE", self, self.onResolveRune) -- 背包获取新灵纹更新分解数据
end

function Lua_RuneResolvePanel:onResolveRune()
	self.resolveArr:clear();
	for i = 1, self.resolveList:getSize() do
		if self.resolveList[i].isSelect == true then
			self.resolveArr:add({id = self.resolveList[i].vo.id, index = self.resolveList[i].vo.index, type = self.resolveList[i].vo.rune_type,
			color = self.resolveList[i].vo.color, decompose = self.resolveList[i].vo.decompose, decomposeCrystal = self.resolveList[i].vo.decomposeCrystal});        
		end
	end

	if self.resolveArr:getSize() > 0  then
		local resolveNum = DataCenter.runeUtil:runeResolveNum(self.resolveArr);
		local crystalNum = DataCenter.runeUtil:runeCrystalNum(self.resolveArr);
		self.chipLab.text = LanUtil.formateStr(LanUtil.getValue(121524),tostring(DataCenter.runeData.ownEssence),tostring(resolveNum));
		if crystalNum > 0 then
			self.chipTips.text = LanUtil.formateStr(LanUtil.getValue(121535),tostring(DataCenter.runeData.ownEcrystal),tostring(crystalNum));
		else
			self.chipTips.text = LanUtil.formateStr(LanUtil.getValue(121534),tostring(DataCenter.runeData.ownEcrystal));
		end
	else
		self.chipLab.text = LanUtil.formateStr(LanUtil.getValue(121523),tostring(DataCenter.runeData.ownEssence));
		self.chipTips.text = LanUtil.formateStr(LanUtil.getValue(121534),tostring(DataCenter.runeData.ownEcrystal));
	end

	-- 红点显示
	self:updateIsShowResolveRed();
end

-- 点击 单个灵纹 刷新界面
function Lua_RuneResolvePanel:onSelectInfo()
	self:onResolveRune();
	self:updateSelect();
end

function Lua_RuneResolvePanel:onUpdateRecords()
	local bagData = DataCenter.packData:getBagType(Lua_PackData.LW_PACK); -- 灵纹背包
	local arr = bagData:getBagAllData(); 
	self.resolveList = Array();     
	local len = arr:getSize();
	for i = 1, len do
		for j = i + 1, len do
			if not self:sortFun(arr[i], arr[j]) then
				local temp = arr[i]
				arr[i] = arr[j]
				arr[j] = temp
			end
		end
		self.resolveList:add({vo = arr[i], isSelect = self:checkSelect(arr[i])});
	end
	self.recordsList:setLuaArrayData(self.resolveList, false);
end

function Lua_RuneResolvePanel:sortFun(a, b)
	if a == nil or b == nil then
		return false;
	end

	if a.color > b.color then
		return true;
	elseif a.color == b.color then
		if tonumber(a.id) > tonumber(b.id) then
			return true;
		elseif tonumber(a.id) == tonumber(b.id) then
			if a.rune_level > b.rune_level then
				return true;
			end
		end
	end
	return false;
end

function Lua_RuneResolvePanel:checkSelect(vo)
	if vo == nil then
		return false;
	end

	if vo.color == 2 then
		if self.blueCheckBox.seleted == true then
			return true;
		end
	elseif vo.color == 3 then
		if self.purpleCheckBox.seleted == true then
			return true;
		end
	elseif vo.color == 4 then
		if self.orangeCheckBox.seleted == true then
			return true;
		end
	elseif vo.color == 5 then
		if self.redCheckBox.seleted == true then
			return true;
		end
	end
	return false;
end


function Lua_RuneResolvePanel:onResolveTipsClick()
	Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {owner = self, des = LanUtil.getValue(121519), type = 1, subFun = self.onSubCallback});
end

function Lua_RuneResolvePanel:onResolveClick()
	local isResolve = false;
	local len = self.resolveArr:getSize()
	if len > 0 then
		for i=1,len do
			if self.resolveArr[i].type ~= 1 then
				if self.resolveArr[i].color == 5 then
					isResolve = true;
				end
			end
		end

		if isResolve == true then
			self:onResolveTipsClick();
		else
			self:onSubCallback();
		end
	else
		OperateAlert.show(LanUtil.getValue(121517));
	end
end

function Lua_RuneResolvePanel:onSubCallback()
	Lua_ProxyManager.getProxy("Lua_RuneProxy"):sResolveRune(self.resolveArr);
end

-- 设置特殊灵纹 默认选择
function Lua_RuneResolvePanel:exeRuneSelect()
	if self.resolveList ~= nil then
		local vo;
		for i = 1, self.resolveList:getSize() do
			vo = self.resolveList[i].vo;
			if vo.rune_type == 1 then
				self.resolveList[i].isSelect = self.blueCheckBox.seleted or self.purpleCheckBox.seleted or self.orangeCheckBox.seleted or self.redCheckBox.seleted;
			end
		end
	end
	self:onResolveRune();
	self:updateSelect();
end

-- 点击CheckBox 更新drag
function Lua_RuneResolvePanel:updateList(color, state)
	if self.resolveList ~= nil then
		local vo;
		for i = 1, self.resolveList:getSize() do
			vo = self.resolveList[i].vo;
			if vo.color == color then
				self.resolveList[i].isSelect = state;
			end
		end
	end 
end

function Lua_RuneResolvePanel:onBlueBoxClick(state)
	self:updateList(2, state);
	self:updateSelect();
	self:onResolveRune();
	self:exeRuneSelect();
end

function Lua_RuneResolvePanel:onPurpleBoxClick(state)
	self:updateList(3, state);
	self:updateSelect();
	self:onResolveRune();
	self:exeRuneSelect();
end

function Lua_RuneResolvePanel:onOrangeBoxClick(state)
	self:updateList(4, state);
	self:updateSelect();
	self:onResolveRune();
	self:exeRuneSelect();
end

function Lua_RuneResolvePanel:onRedBoxClick(state)
	self:updateList(5, state);
	self:updateSelect();
	self:onResolveRune();
	self:exeRuneSelect();
end

function Lua_RuneResolvePanel:updateSelect()
	if self.recordsList ~= nil then
		local arr = self.recordsList.showList;
		for i = 1, arr:getSize() do
			arr[i]:updateSelect();
		end
	end
end

-- 红点更新
function Lua_RuneResolvePanel:updateIsShowResolveRed()
	local isShowResolveRed = DataCenter.runeData:isShowResolveRed();
	self:showRedDot(isShowResolveRed); -- 分解红点显示
end

-- 红点显示
function Lua_RuneResolvePanel:showRedDot(val)
	if val == true then
		if self.redDot == nil then
			self.redDot = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_hongdian", 479, -290, 0, 0);
			self.redDot:setDepth(7);
			self.redDot.name = "redDot";
		end
		self.redDot:setEnable(true);
	else
		if self.redDot ~= nil then
			self.redDot:setEnable(false);
		end
	end
end

function Lua_RuneResolvePanel:showResolveEffect()
	if self.effect1 == nil then
		self.effect1 = UICreate.createUIEffect(self.content, "/effects/scsEffects/gui_lingwenxiaoguo", "gui_lingwenxiaoguo", -399, 32);
	else
		self.effect1.mainContent:SetActive(false);
		self.effect1.mainContent:SetActive(true);
	end
	self.effect1:SetRenderQueue(self.effectBg, 10, 2,false);
end

function Lua_RuneResolvePanel:onOpenRuneStoneTips()
	Lua_PackUtil.showItemInfo(Lua_ToolVo.new(201060102), false)
end

function Lua_RuneResolvePanel:onOpenRuneSoulTips()
	Lua_PackUtil.showItemInfo(Lua_ToolVo.new(201060101), false)
end

function Lua_RuneResolvePanel:dispose()
	if self.resolveArr ~= nil then
		self.resolveArr:dispose();
		self.resolveArr:clear();
		self.resolveArr = nil; 
	end
	if self.recordsList ~= nil then
		self.recordsList:dispose()
		self.recordsList = nil;
	end
	if self.resolveList ~= nil then
		self.resolveList:dispose();
		self.resolveList:clear();
		self.resolveList = nil; 
	end
	if self.redDot ~= nil then
		self.redDot:dispose();
		self.redDot = nil;
	end
	if self.effect1 ~= nil then
		self.effect1:dispose();
		self.effect1 = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_RuneResolveItem = class("Lua_RuneResolveItem", Lua_ListCell);
function Lua_RuneResolveItem:ctor(p)
	self:superCall("ctor", p, "RuneResolveItem_skin");
end

function Lua_RuneResolveItem:buildShowItem()
	self:superCall("buildShowItem");

	self.pro = {self.runeDesLab1, self.runeDesLab2}; 
end

 function Lua_RuneResolveItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end
	self.vo = data.vo;

	self.runeIcon:setAltas("item3", tostring(self.vo.id));
	self.runeLvLab.text = self.vo.runeName;

	local arr = self.vo.runeProp;
	self.pro[2]:setEnable(false);
	if self.vo.rune_type == 1 then
		self.pro[1].text = self.vo.runeExeProp;
		self.pro[2].text = "";
	else
		if arr:getSize() > 1 then
			self.pro[2]:setEnable(true);
		end

		for i = 1, arr:getSize() do
			if arr[i].type == 1 then
				self.pro[i].text = LanUtil.formateStr(LanUtil.getValue(121522), tostring(arr[i].runePropName), tostring(arr[i].runePropNum));
			elseif arr[i].type == 2 then
				self.pro[i].text = LanUtil.formateStr(LanUtil.getValue(121522), tostring(arr[i].runePropName), tostring(arr[i].runePropNum)).."%"; 
			end
		end
	end
	self:updateSelect();
 end

function Lua_RuneResolveItem:updateSelect()
	self.selectIcon:setEnable(self.data.isSelect);
end

function Lua_RuneResolveItem:onPlayerSoundClick(go)
	self.data.isSelect = not self.data.isSelect;
	Lua_MsgUtil.callFunc("ISSELCET");
end

function Lua_RuneResolveItem:dispose()
	self:superCall("dispose");
end