-- 魂印分解
Lua_StampResolveWindow = class("Lua_StampResolveWindow", Lua_SecondSizeWindow)
function Lua_StampResolveWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_StampResolveWindow";
	self.skinName = "StampResolveWindow_skin";
	self.titleText = LanUtil.getValue(128504);
end

function Lua_StampResolveWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.resolveArr = Array();

	self.recordsList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 1023, 367));
	self.recordsList:setLocation(0, 20, 0);
	self.recordsList:setListCell(Lua_StampResolveItem, 102, 102, 10);

	self.soulSp.clickScale = false;
	self.soulSp:addClickFuntion(self, self.onOpenStampStoneTips);

	self.help:addClickFuntion(self, self.onHelpClick);
	self.resolveBtn:addClickFuntion(self, self.onResolveClick);

	self.subBtn1:addClickFuntion(self, self.onSelectColorClick); -- 选择分解类型
	self.subBtn2:addClickFuntion(self, self.onSelectStepsClick); -- 选择分解阶位
	self:setSelectType(DataCenter.stampData.select_color);
	self:setSelectSteps(DataCenter.stampData.select_order);

	self.selectCheckBox:addBoxChange(self, self.onSelectBoxClick); -- 自动分解选择

	self:onUpdatePackInfo();
	self:onResolveStampData();

	self:addLuaEvent("UPDATE_STAMP_INFO", self, self.onResolveStampData);

	self:addLuaEvent("UPDATE_STAMP_SELCET", self, self.onSelectInfo);
	self:addLuaEvent("RESOLVE_STAMP_INFO", self, self.onUpdatePackInfo); -- 分解灵纹后刷新界面
	self:addLuaEvent("PACK_STAMP_UPDATE", self, self.onUpdatePackInfo); -- 背包获取新魂印后刷新界面
	self:addLuaEvent("PACK_STAMP_UPDATE", self, self.onResolveStampData); -- 背包获取新魂印更新分解数据
end

function Lua_StampResolveWindow:onSelectColorClick(go)
	local dragData = {};
	dragData.datas = Array();
	dragData.datas:add(LanUtil.getValue(124423));
	dragData.datas:add(LanUtil.getValue(124424));
	dragData.datas:add(LanUtil.getValue(124425));
	dragData.datas:add(LanUtil.getValue(124426));
	dragData.datas:add(LanUtil.getValue(124427));
	dragData.offsetX = -435;
	dragData.offsetY = -94;
	dragData.callBackOwner = self;
	dragData.callBack = self.onColorCallBack;
	dragData.selected = self.selectType;
	Lua_WindowUtil.openWin("Lua_DragDownWindow", nil, dragData);
end

function Lua_StampResolveWindow:onColorCallBack(val)
	DataCenter.stampData.select_color = val;
	self:setSelectType(val);
	self:onUpdatePackInfo(); -- 背包数据
	self:onResolveStampData();
end

function Lua_StampResolveWindow:setSelectType(val)
	self.selectType = val;
	self.subTxt1.text = LanUtil.getValue(124416 + val);
end

function Lua_StampResolveWindow:onSelectStepsClick(go)
	local dragData = {
		LanUtil.getValue(128505),
		LanUtil.getValue(128506),
		LanUtil.getValue(128507),
		LanUtil.getValue(128508),
		LanUtil.getValue(128509),
		LanUtil.getValue(128510),
		LanUtil.getValue(128511),
		LanUtil.getValue(128512),
		LanUtil.getValue(128513),
		LanUtil.getValue(128514),
		LanUtil.getValue(128515),
		LanUtil.getValue(128516),
		LanUtil.getValue(128517),
		LanUtil.getValue(128537),
		LanUtil.getValue(128538),
		LanUtil.getValue(128539)
	};
	
	dragData.datas = Array();
	for i,v in ipairs(dragData) do
		if DataCenter.stampUtil.open_order[i] ~= nil then
			dragData.datas:add(v)
		end
	end
	dragData.offsetX = -177;
	dragData.offsetY = -94;
	dragData.callBackOwner = self;
	dragData.callBack = self.onStepsCallBack;
	dragData.selected = self.selectSteps;
	Lua_WindowUtil.openWin("Lua_DragDownWindow", nil, dragData);
end

function Lua_StampResolveWindow:onStepsCallBack(val)
	DataCenter.stampData.select_order = val;
	self:setSelectSteps(val);
	self:onUpdatePackInfo(); -- 背包数据
	self:onResolveStampData();
end

function Lua_StampResolveWindow:setSelectSteps(val)
	self.selectSteps = val;
	if val < 14 then
		self.subTxt2.text = LanUtil.getValue(128504 + val);
	elseif val < 17 then
		self.subTxt2.text = LanUtil.getValue(128523 + val);
	end
end

-- 分解数据
function Lua_StampResolveWindow:onResolveStampData()
	self.resolveArr:clear();
	for i = 1, self.resolveList:getSize() do
		if self.resolveList[i].isSelect == true then
			self.resolveArr:add({id = self.resolveList[i].vo.id, index = self.resolveList[i].vo.index, color = self.resolveList[i].vo.color,
			decompose = self.resolveList[i].vo.decompose, type = self.resolveList[i].vo.stamp_type});
		end
	end

	if self.resolveArr:getSize() > 0  then
		local resolveNum = DataCenter.stampUtil:stampResolveNum(self.resolveArr);
		self.resolveTxt.text = LanUtil.formateStr(LanUtil.getValue(128524), tostring(DataCenter.stampData.stamp_crystal),tostring(resolveNum));
	else
		self.resolveTxt.text = LanUtil.formateStr(LanUtil.getValue(128525), tostring(DataCenter.stampData.stamp_crystal));
	end
	self:updateCardResolveRed();
end

-- 点击 单个灵纹 刷新界面
function Lua_StampResolveWindow:onSelectInfo()
	self:onResolveStampData();
	self:updateSelect();
end

-- 背包数据
function Lua_StampResolveWindow:onUpdatePackInfo()
	local len = DataCenter.stampUtil.pack_size;
	local bagData = DataCenter.packData:getBagType(Lua_PackData.STAMP_PACK); -- 魂印-背包
	local arr = bagData:getItemsBySubType({Lua_PackTypeDefine.STAMP_ITEM});
	self.resolveList = Array()
	for i = 1, len do
		if arr[i] ~= nil then
			local weight = 0;
			if arr[i].stamp_type  == 0 then
				weight = arr[i].color; 
			else
				weight = 100000 + arr[i].color * 1000 + arr[i].order;
			end
			self.resolveList:add({vo = arr[i], isSelect = self:checkSelect(arr[i]), weight=weight});
		else
			self.resolveList:add({vo = nil, isSelect = false, weight=0});
		end
	end
	self.resolveList:sort("weight", true);
	self.recordsList:setLuaArrayData(self.resolveList, false);

	self.selectCheckBox.seleted = DataCenter.stampData.isAutoStampResolve ~= 0;
end

function Lua_StampResolveWindow:checkSelect(vo)
	if vo == nil then
		return false;
	end

	if (self.selectType == 1 and vo.color == 1 and  vo.order <= self.selectSteps) or vo.stamp_type == 0 then
		return true;
	elseif (self.selectType == 2 and vo.color <= 2 and vo.order <= self.selectSteps) or vo.stamp_type == 0 then
		return true;
	elseif (self.selectType == 3 and vo.color <= 3 and vo.order <= self.selectSteps) or vo.stamp_type == 0 then
		return true;
	elseif (self.selectType == 4 and vo.color <= 4 and vo.order <= self.selectSteps) or vo.stamp_type == 0 then
		return true;
	elseif (self.selectType == 5 and vo.color <= 5 and vo.order <= self.selectSteps) or vo.stamp_type == 0 then
		return true;
	end
	return false;
end

function Lua_StampResolveWindow:onResolveTipsClick()
	Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {owner = self, des = LanUtil.getValue(128527), type = 1, subFun = self.onSubCallback});
end

function Lua_StampResolveWindow:onResolveClick()
	local isResolve = false;
	local len = self.resolveArr:getSize()
	if len > 0 then
		for i = 1, len do
			if self.resolveArr[i].type ~= 0 then
				if self.resolveArr[i].color >= 4 then
					isResolve = true;
				end
			end
		end

		if isResolve == true then
			self:onResolveTipsClick();
		else
			self:onSubCallback();
		end
	else
		OperateAlert.show(LanUtil.getValue(128549));
	end
end

function Lua_StampResolveWindow:onSubCallback()
	Lua_ProxyManager.getProxy("Lua_StampProxy"):sResolveStamp(self.resolveArr);
	if self.resolveList ~= nil then
		self.resolveList:clear();
	end

	if self.resolveArr ~= nil then
		self.resolveArr:clear();
	end
end

-- 0关，1开
function Lua_StampResolveWindow:onSelectBoxClick(state)
	local num = state and 1 or 0;
	Lua_ProxyManager.getProxy("Lua_StampProxy"):sAutoResolveStamp(num);
	DataCenter.stampData.isAutoStampResolve = num;
end

function Lua_StampResolveWindow:updateSelect()
	if self.recordsList ~= nil then
		for i = 1, self.recordsList.showList:getSize() do
			self.recordsList.showList[i]:updateSelect();
		end
	end
end

function Lua_StampResolveWindow:updateCardResolveRed()
	local isShowResolveRed = DataCenter.stampData:isShowStampResolveRed();
	self:showRedDot(isShowResolveRed);
end

function Lua_StampResolveWindow:showRedDot(val)
	if val then
		if self._redDot == nil then
			self._redDot = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_hongdian", 532, -231, 0, 0);
			self._redDot:setDepth(7);
			self._redDot.name = "redDot";
		end
		self._redDot:setEnable(true);
	else
		if self._redDot ~= nil then
			self._redDot:setEnable(false);
		end
	end
end

function Lua_StampResolveWindow:onOpenStampStoneTips()--魂石Tips
	Lua_PackUtil.showItemInfo(Lua_ToolVo.new(201050021),false)
end

function Lua_StampResolveWindow:onHelpClick()
	Lua_WindowUtil.openWin("Lua_RuleTipWindow", WinParam.ACTION_AUTO, LanUtil.getValue(128526));
end

function Lua_StampResolveWindow:dispose()
	if self.resolveArr ~= nil then
		self.resolveArr:dispose();
		self.resolveArr:clear();
		self.resolveArr = nil; 
	end
	if self.recordsList ~= nil then
		self.recordsList:dispose()
		self.recordsList = nil;
	end
	if self.resolveList ~= nil then
		self.resolveList:dispose();
		self.resolveList:clear();
		self.resolveList = nil; 
	end
	if self._redDot ~= nil then
		self._redDot:dispose()
		self._redDot = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_StampResolveItem = class("Lua_StampResolveItem", Lua_ListCell);
function Lua_StampResolveItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_StampResolveItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemImage = Lua_ToolImage.new(self.content);
	self.itemImage:setDefaultIcon("common_atlas_1", "ui_common_prop_9");
	self.itemImage:setDepth(3);
	self.itemImage:setLocation(0, 6, 0);
	self.itemImage:setCanClick(false);
end

 function Lua_StampResolveItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.itemImage.data = data.vo;
	if data.vo ~= nil then
		self.itemImage:showStampEff(data.vo.stamp_type ~= 0);
	end
	self:updateSelect();
 end

function Lua_StampResolveItem:updateSelect()
	if self.data.isSelect == true then
		if self._drawIcon == nil then
			self._drawIcon = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_xz", 0, 0, 0, 0);
			self._drawIcon.name = "drawIcon";
			self._drawIcon:setDepth(10);
		end
		self._drawIcon:setEnable(true);
		self.itemImage:setGray(true);
	else
		if self._drawIcon ~= nil then
			self._drawIcon:setEnable(false);
		end
		self.itemImage:setGray(false);
	end
end

function Lua_StampResolveItem:checkOutBound(showRect)
	if self.data == nil or self.data.vo == nil then
		self.inViewEffect = false;
		return;
	end

	local rect = Lua_Rectangle.new(self.itemX - 40, self.itemY - 24, 70,60);
	if showRect:containeRect(rect) == true then
		if self.data.vo.stamp_type == 0 then
			self.inViewEffect = false;
		else
			self.inViewEffect = self.data.vo.color >= 2;
		end
	else
		self.inViewEffect = false;
	end
	self:updateEffectState();
end

function Lua_StampResolveItem:updateEffectState()
	if self.inViewEffect == true then
		if self.itemImage.stampEff == nil then
			self.itemImage:showStampEff(true);
		end
	else
		self.itemImage:showStampEff(false);
	end
end

function Lua_StampResolveItem:onPlayerSoundClick(go)
	if self.data.vo ~= nil then
		self.data.isSelect = not self.data.isSelect;
		Lua_MsgUtil.callFunc("UPDATE_STAMP_SELCET");
	end
end

function Lua_StampResolveItem:dispose()
	if self.itemImage ~= nil then
		self.itemImage:dispose();
		self.itemImage = nil;
	end
	if self._drawIcon ~= nil then
		self._drawIcon:dispose();
		self._drawIcon = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end